AEADSession class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(List<int> data, List<int> additionalData, List<int> nonce) Uint8List?
seal(List<int> data, List<int> additionalData, List<int> nonce) Uint8List?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

initSession(Uint8List key, AEADAlgorithm aeadAlgorithm, {int? tagLength}) AEADSession?